===============================
analyzerstrategies
===============================

.. image:: https://badge.fury.io/py/analyzerstrategies.png
    :target: http://badge.fury.io/py/analyzerstrategies

.. image:: https://travis-ci.org/llazzaro/analyzerstrategies.png?branch=master
        :target: https://travis-ci.org/llazzaro/analyzerstrategies

.. image:: https://pypip.in/d/analyzerstrategies/badge.png
        :target: https://pypi.python.org/pypi/analyzerstrategies


Analyzer Strategies

Features
=========

* TODO